@@ -14,14 +14,100 @@ def coerceDType(d):
   else:
     return d
 
+def Inversion(Qsca,Qabs,wavelength,diameter,nMin=1,nMax=3,kMin=0,kMax=1,scatteringPrecision=0.02,absorptionPrecision=0.03,spaceSize=120,interp=2):
+  error = lambda measured,calculated: np.abs((calculated-measured)/measured)
+  
+  nRange = np.linspace(nMin,nMax,spaceSize)
+  kRange = np.linspace(kMin,kMax,spaceSize)
+  scaSpace = np.zeros((spaceSize,spaceSize))
+  absSpace = np.zeros((spaceSize,spaceSize))
+
+  for ni,n in enumerate(nRange):
+    for ki,k in enumerate(kRange):
+      _derp = fastMieQ(n+(1j*k),wavelength,diameter)
+      scaSpace[ni][ki] = _derp[0]
+      absSpace[ni][ki] = _derp[1]
+  if interp is not None:
+    nRange = zoom(nRange,interp)
+    kRange = zoom(kRange,interp)
+    scaSpace = zoom(scaSpace,interp)
+    absSpace = zoom(absSpace,interp)
+    
+  scaSolutions = np.where(np.logical_and(Qsca*(1-scatteringPrecision)<scaSpace, scaSpace<Qsca*(1+scatteringPrecision)))
+  absSolutions = np.where(np.logical_and(Qabs*(1-absorptionPrecision)<absSpace, absSpace<Qabs*(1+absorptionPrecision)))
+
+  validScattering = nRange[scaSolutions[0]]+1j*kRange[scaSolutions[1]]
+  validAbsorption = nRange[absSolutions[0]]+1j*kRange[absSolutions[1]]
+  
+  solution = np.intersect1d(validScattering,validAbsorption)
+#  errors = [error()]
+
+  return solution
+
+def Inversion_SD(Bsca,Babs,wavelength,dp,ndp,nMin=1,nMax=3,kMin=0,kMax=1,spaceSize=40,interp=2):
+  dp = coerceDType(dp)
+  ndp = coerceDType(ndp)
+
+  nRange = np.linspace(nMin,nMax,spaceSize)
+  kRange = np.linspace(kMin,kMax,spaceSize)
+  scaSpace = np.zeros((spaceSize,spaceSize))
+  absSpace = np.zeros((spaceSize,spaceSize))
+
+  for ni,n in enumerate(nRange):
+    for ki,k in enumerate(kRange):
+      _derp = fastMie_SD(n+(1j*k),wavelength,dp,ndp)
+      scaSpace[ni][ki] = _derp[0]
+      absSpace[ni][ki] = _derp[1]
+  if interp is not None:
+    nRange = zoom(nRange,interp)
+    kRange = zoom(kRange,interp)
+    scaSpace = zoom(scaSpace,interp)
+    absSpace = zoom(absSpace,interp)
+
+  scaP = 0.02
+  absP = 0.03
+  scaSolutions = np.where(np.logical_and(Bsca*(1-scaP)<scaSpace, scaSpace<Bsca*(1+scaP)))
+  absSolutions = np.where(np.logical_and(Babs*(1-absP)<absSpace, absSpace<Babs*(1+absP)))
+
+  validScattering = nRange[scaSolutions[0]]+1j*kRange[scaSolutions[1]]
+  validAbsorption = nRange[absSolutions[0]]+1j*kRange[absSolutions[1]]
+
+  return np.intersect1d(validScattering,validAbsorption)
+
 def GraphicalInversion(QscaMeasured,QabsMeasured,wavelength,diameter,nMin=1,nMax=3,kMin=0.00001,kMax=1,QbackMeasured=None,gridPoints=200,interpolationFactor=2,maxError=0.005,makePlot=True,axisOption=0,returnGraphElements=False,annotation=True):
 #  http://pymiescatt.readthedocs.io/en/latest/inverse.html#GraphicalInversion
   error = lambda measured,calculated: np.abs((calculated-measured)/measured)
+  labels = []
+  if type(QscaMeasured) in [list, tuple, np.ndarray]:
+    scaError = QscaMeasured[1]
+    QscaMeasured = QscaMeasured[0]
+    labels.append("Qsca = {b:1.3f}±{e:1.3f}".format(b=QscaMeasured,e=scaError))
+  else:
+    scaError = None
+    labels.append("Qsca = {b:1.3f}".format(b=QscaMeasured))
+  if type(QabsMeasured) in [list, tuple, np.ndarray]:
+    absError = QabsMeasured[1]
+    QabsMeasured = QabsMeasured[0]
+    labels.append("Qabs = {b:1.3f}±{e:1.3f}".format(b=QabsMeasured,e=absError))
+  else:
+    absError = None
+    labels.append("Qabs = {b:1.3f}".format(b=QabsMeasured))
+  if type(QbackMeasured) in [list, tuple, np.ndarray]:
+    backError = QbackMeasured[1]
+    QbackMeasured = QbackMeasured[0]
+    labels.append("Qback = {b:1.3f}±{e:1.3f}".format(b=QbackMeasured,e=backError))
+  elif QbackMeasured is not None:
+    backError = None
+    labels.append("Qback - {b:1.3f}".format(b=QbackMeasured))
+  else:
+    backError = None
+
   if (gridPoints*interpolationFactor) < 400:
     if QbackMeasured is not None:
       warnings.warn("If the product of gridPoints and interpolationFactor is less than 400, a unique solution may not be found!")
     else:
       warnings.warn("If the product of gridPoints and interpolationFactor is less than 400, not all solutions may be found, and errors may be high. Increase gridPoints to improve performance.")
+
   nRange = np.linspace(nMin,nMax,gridPoints)
   kRange = np.logspace(np.log10(kMin),np.log10(kMax),gridPoints)
   QscaList = []
@@ -46,24 +132,35 @@ def GraphicalInversion(QscaMeasured,QabsMeasured,wavelength,diameter,nMin=1,nMax
 
   n = zoom(nRange,interpolationFactor)
   k = zoom(kRange,interpolationFactor)
-  if makePlot:
-    plt.ion()
-  else:
-    plt.ioff()
 
   fig = plt.figure(figsize=(8.5,8.5))
   ax = fig.gca()
 
   scaLevels = np.array([QscaMeasured])
   absLevels = np.array([QabsMeasured])
+
   if QbackMeasured is not None:
     backLevels = np.array([QbackMeasured])
+    if backError is not None:
+      backErrorLevels = np.array([QbackMeasured+x for x in [-backError,backError]])
 
   scaChart = ax.contour(n,k,QscaList,scaLevels,origin='lower',linestyles='dashdot',linewidths=1.5,colors=('red'))
   absChart = ax.contour(n,k,QabsList,absLevels,origin='lower',linewidths=1.5,colors=('blue'))
   if QbackMeasured is not None:
     backChart = ax.contour(n,k,QbackList,backLevels,origin='lower',linestyles='dotted',linewidths=1.5,colors=('green'))
 
+  if scaError is not None:
+    scaErrorLevels = np.array([QscaMeasured+x for x in [-scaError, scaError]])
+    scaErrorChart = ax.contourf(n,k,QscaList,scaErrorLevels,origin='lower',colors=('red'),alpha=0.15)
+    ax.contour(n,k,QscaList,scaErrorLevels,origin='lower',linewidths=0.5,colors=('red'),alpha=0.5)
+  if absError is not None:
+    absErrorLevels = np.array([QabsMeasured+x for x in [-absError, absError]])
+    absErrorChart = ax.contourf(n,k,QabsList,absErrorLevels,origin='lower',colors=('blue'),alpha=0.15)
+    ax.contour(n,k,QabsList,absErrorLevels,origin='lower',linewidths=0.5,colors=('blue'),alpha=0.5)
+  if backError is not None:
+    backErrorLevels = np.array([QbackMeasured+x for x in [-backError, backError]])
+    backErrorChart = ax.contourf(n,k,QbackList,backErrorLevels,origin='lower',colors=('green'),alpha=0.15)
+    ax.contour(n,k,QbackList,backErrorLevels,origin='lower',linewidths=0.5,colors=('green'),alpha=0.5)
   distinctScaPaths = len(scaChart.collections[0].get_paths())
   distinctAbsPaths = len(absChart.collections[0].get_paths())
   if QbackMeasured is not None:
@@ -124,10 +221,17 @@ def GraphicalInversion(QscaMeasured,QabsMeasured,wavelength,diameter,nMin=1,nMax
   solutionSet = solutionSet[solution]
   forwardCalculations = forwardCalculations[solution]
   solutionErrors = solutionErrors[solution]
+  _sS = [x[0] for x in solutionErrors]
+  _sA = [x[1] for x in solutionErrors]
+  _sR = [[np.min(_sS), np.max(_sS)],[np.min(_sA), np.max(_sA)]]
   nSolutionsToPlot,kSolutionsToPlot = [x.real for x in solutionSet],[x.imag for x in solutionSet]
 
   solutions = ax.scatter(nSolutionsToPlot,kSolutionsToPlot,marker='o',s=128,linewidth=1.5,edgecolor='k',facecolor='none',zorder=3)
   solutions = ax.scatter(nSolutionsToPlot,kSolutionsToPlot,marker='o',s=128,linewidth=0,edgecolor='none',facecolor='c',zorder=1,alpha=0.25)
+  for x,y,s in zip(nSolutionsToPlot,kSolutionsToPlot,solutionErrors):
+    plt.axhline(y,linewidth=0.5,color=str(np.interp(s[0],_sR[0],[0.15,1])),zorder=0)
+    plt.axvline(x,linewidth=0.5,color=str(np.interp(s[1],_sR[1],[0.15,1])),zorder=0)
+
   ax.set_xlabel('n',fontsize=16)
   ax.set_ylabel('k',fontsize=16)
 
@@ -165,11 +269,9 @@ def GraphicalInversion(QscaMeasured,QabsMeasured,wavelength,diameter,nMin=1,nMax
     pass
 
   lines = [scaChart.collections[0], absChart.collections[0]]
-  labels = ["Qsca = {q:1.3f}".format(q=QscaMeasured),"Qabs = {q:1.3f}".format(q=QabsMeasured)]
   graphelements = [fig,ax,st,solutions,scaChart,absChart]
   if QbackMeasured is not None:
     lines.append(backChart.collections[0])
-    labels.append("Qback = {q:1.3f}".format(q=QbackMeasured))
     graphelements.append(backChart)
 
   plt.legend(lines,labels,fontsize=16)
@@ -183,10 +285,35 @@ def GraphicalInversion(QscaMeasured,QabsMeasured,wavelength,diameter,nMin=1,nMax
   else:
     return solutionSet,forwardCalculations,solutionErrors
 
-def GraphicalInversion_withSizeDistribution(BscaMeasured,BabsMeasured,wavelength,diameterBins,concentration,nMin=1,nMax=3,kMin=0.00001,kMax=1,gridPoints=60,interpolationFactor=2,maxError=0.005,axisOption=0,returnGraphElements=False,annotation=True,SDinset=False):
-#  http://pymiescatt.readthedocs.io/en/latest/inverse.html#GraphicalInversion_withSizeDistribution
+def GraphicalInversion_SD(BscaMeasured,BabsMeasured,wavelength,dp,concentration,nMin=1,nMax=3,kMin=0.00001,kMax=1,BbackMeasured=None,gridPoints=60,interpolationFactor=2,maxError=0.005,axisOption=0,returnGraphElements=False,annotation=True,SDinset=False):
+#  http://pymiescatt.readthedocs.io/en/latest/inverse.html#GraphicalInversion_withndp
   error = lambda measured,calculated: np.abs((calculated-measured)/measured)
-  diameterBins = coerceDType(diameterBins)
+  labels = []
+  if type(BscaMeasured) in [list, tuple, np.ndarray]:
+    scaError = BscaMeasured[1]
+    BscaMeasured = BscaMeasured[0]
+    labels.append("Bsca = {b:1.1f}±{e:1.1f}".format(b=BscaMeasured,e=scaError))
+  else:
+    scaError = None
+    labels.append("Bsca = {b:1.1f}".format(b=BscaMeasured))
+  if type(BabsMeasured) in [list, tuple, np.ndarray]:
+    absError = BabsMeasured[1]
+    BabsMeasured = BabsMeasured[0]
+    labels.append("Babs = {b:1.1f}±{e:1.1f}".format(b=BabsMeasured,e=absError))
+  else:
+    absError = None
+    labels.append("Babs = {b:1.1f}".format(b=BabsMeasured))
+  if type(BbackMeasured) in [list, tuple, np.ndarray]:
+    backError = BbackMeasured[1]
+    BbackMeasured = BbackMeasured[0]
+    labels.append("Bback = {b:1.1f}±{e:1.1f}".format(b=BbackMeasured,e=backError))
+  elif BbackMeasured is not None:
+    backError = None
+    labels.append("Qback - {b:1.3f}".format(b=BbackMeasured))
+  else:
+    backError = None
+
+  dp = coerceDType(dp)
   concentration = coerceDType(concentration)
   nRange = np.linspace(nMin,nMax,gridPoints)
   kRange = np.logspace(np.log10(kMin),np.log10(kMax),gridPoints)
@@ -198,7 +325,7 @@ def GraphicalInversion_withSizeDistribution(BscaMeasured,BabsMeasured,wavelength
     a = []
     for k in kRange:
       m = n+k*1.0j
-      Bsca,Babs = fastMie_withSizeDistribution(m,wavelength,diameterBins,concentration)
+      Bsca,Babs = fastMie_SD(m,wavelength,dp,concentration)
       s.append(Bsca)
       a.append(Babs)
     BscaList.append(s)
@@ -218,6 +345,19 @@ def GraphicalInversion_withSizeDistribution(BscaMeasured,BabsMeasured,wavelength
   scaChart = ax.contour(n,k,BscaList,scaLevels,origin='lower',linestyles='dashdot',linewidths=1.5,colors=('red'))
   absChart = ax.contour(n,k,BabsList,absLevels,origin='lower',linewidths=1.5,colors=('blue'))
 
+  if scaError is not None:
+    scaErrorLevels = np.array([BscaMeasured+x for x in [-scaError, scaError]])
+    scaErrorChart = ax.contourf(n,k,BscaList,scaErrorLevels,origin='lower',colors=('red'),alpha=0.15)
+    ax.contour(n,k,BscaList,scaErrorLevels,origin='lower',linewidths=0.5,colors=('red'),alpha=0.5)
+  if absError is not None:
+    absErrorLevels = np.array([BabsMeasured+x for x in [-absError, absError]])
+    absErrorChart = ax.contourf(n,k,BabsList,absErrorLevels,origin='lower',colors=('blue'),alpha=0.15)
+    ax.contour(n,k,BabsList,absErrorLevels,origin='lower',linewidths=0.5,colors=('blue'),alpha=0.5)
+#  if backError is not None:
+#    backErrorLevels = np.array([BbackMeasured+x for x in [-backError, backError]])
+#    backErrorChart = ax.contourf(n,k,BbackList,backErrorLevels,origin='lower',colors=('green'),alpha=0.15)
+#    ax.contour(n,k,BbackList,backErrorLevels,origin='lower',linewidths=0.5,colors=('green'),alpha=0.5)
+
   distinctScaPaths = len(scaChart.collections[0].get_paths())
   distinctAbsPaths = len(absChart.collections[0].get_paths())
   scaVertices = []
@@ -235,7 +375,7 @@ def GraphicalInversion_withSizeDistribution(BscaMeasured,BabsMeasured,wavelength
 
   forwardCalculations = []
   for s in solutionSet:
-    _s,_a = fastMie_withSizeDistribution(s,wavelength,diameterBins,concentration)
+    _s,_a = fastMie_SD(s,wavelength,dp,concentration)
     forwardCalculations.append([_s,_a])
   solutionErrors = []
   for f in forwardCalculations:
@@ -259,6 +399,9 @@ def GraphicalInversion_withSizeDistribution(BscaMeasured,BabsMeasured,wavelength
 
   solutions = ax.scatter(nSolution,kSolution,marker='o',s=128,linewidth=1.5,edgecolor='k',facecolor='none',zorder=3)
   solutions = ax.scatter(nSolution,kSolution,marker='o',s=128,linewidth=0,edgecolor='none',facecolor='c',zorder=1,alpha=0.25)
+  for x,y in zip(nSolution,kSolution):
+    plt.axhline(y,linewidth=0.5,color='0.85',zorder=0)
+    plt.axvline(x,linewidth=0.5,color='0.85',zorder=0)
 
   ax.set_xlabel('n',fontsize=16)
   ax.set_ylabel('k',fontsize=16)
@@ -283,7 +426,7 @@ def GraphicalInversion_withSizeDistribution(BscaMeasured,BabsMeasured,wavelength
     st.patch.set_alpha(0.85)
     ax.add_artist(st)
 
-  if axisOption ==0:
+  if axisOption == 0:
     if max(kSolution) <= 0.5 or kMax <= 1:
       ax.set_yscale('log')
     else:
@@ -299,13 +442,16 @@ def GraphicalInversion_withSizeDistribution(BscaMeasured,BabsMeasured,wavelength
     pass
 
   lines = [scaChart.collections[0], absChart.collections[0]]
-  labels = ["Bsca = {b:1.3f}".format(b=BscaMeasured),"Babs = {b:1.3f}".format(b=BabsMeasured)]
   plt.legend(lines,labels,fontsize=16)
 
+#  if BbackMeasured is not None:
+#    lines.append(backChart.collections[0])
+#    graphelements.append(backChart)
+
   if(SDinset):
     left,bottom,width,height = [0.55,0.5,0.3,0.25]
     ax2=fig.add_axes([left,bottom,width,height],zorder=5)
-    ax2.semilogx(diameterBins,concentration,color='k')
+    ax2.semilogx(dp,concentration,color='k')
     ax2.set_xlabel("Diameter (nm)")
     ax2.set_ylabel("Concentration $\mathregular{(cm^{-3})}$")
     ax2.patch.set_alpha(0.85)
@@ -340,11 +486,10 @@ def find_intersections(A,B):
 
   return xi[arrayAll(xconds)], yi[arrayAll(yconds)]
 
-def IterativeInversion(Qsca,Qabs,wavelength,diameter,tolerance=0.0005,initial_m=1.3+0.0j):
+def IterativeInversion(Qsca,Qabs,wavelength,diameter,tolerance=0.0005):
 #  http://pymiescatt.readthedocs.io/en/latest/inverse.html#IterativeInversion
   error = lambda measured,calculated: np.abs((calculated-measured)/measured)
-  if type(initial_m) not in [list,tuple]:
-    initial_m = [initial_m]
+  initial_m = Inversion(Qsca,Qabs,wavelength,diameter,scatteringPrecision=0.01,absorptionPrecision=0.02,spaceSize=125,interp=2)
   factors = [2.5, 5.0, 10.0, 25.0, 50.0]
   errors = [tolerance*x for x in [25,15,5,3,1]]
   resultM = []
@@ -437,11 +582,12 @@ def IterativeInversion(Qsca,Qabs,wavelength,diameter,tolerance=0.0005,initial_m=
 
   return resultM, resultScaErr, resultAbsErr
 
-def IterativeInversion_withSizeDistribution(Bsca,Babs,wavelength,diameterBins,sizeDistribution,tolerance=0.0005,initial_m=1.3+0.0j):
-#  http://pymiescatt.readthedocs.io/en/latest/inverse.html#IterativeInversion_withSizeDistribution
+def IterativeInversion_SD(Bsca,Babs,wavelength,dp,ndp,tolerance=0.0005):
+#  http://pymiescatt.readthedocs.io/en/latest/inverse.html#IterativeInversion_SD
+  dp = coerceDType(dp)
+  ndp = coerceDType(ndp)
   error = lambda measured,calculated: np.abs((calculated-measured)/measured)
-  if type(initial_m) not in [list,tuple]:
-    initial_m = [initial_m]
+  initial_m = Inversion_SD(Bsca,Babs,wavelength,dp,ndp,spaceSize=50,interp=2)
   factors = [2.5, 5.0, 10.0, 25.0, 50.0]
   errors = [tolerance*x for x in [25,15,5,3,1]]
   resultM = []
@@ -451,7 +597,7 @@ def IterativeInversion_withSizeDistribution(Bsca,Babs,wavelength,diameterBins,si
   for m in initial_m:
     nResolution = 100
     kResolution = 1000
-    trialBsca,trialBabs = fastMie_withSizeDistribution(m,wavelength,diameterBins,sizeDistribution)
+    trialBsca,trialBabs = fastMie_SD(m,wavelength,dp,ndp)
 
     scaError = error(Bsca,trialBsca)
     absError = error(Babs,trialBabs)
@@ -464,7 +610,7 @@ def IterativeInversion_withSizeDistribution(Bsca,Babs,wavelength,diameterBins,si
           break
         scaError_prev = scaError
         m = m+nStep
-        trialBsca,trialBabs = fastMie_withSizeDistribution(m,wavelength,diameterBins,sizeDistribution)
+        trialBsca,trialBabs = fastMie_SD(m,wavelength,dp,ndp)
         scaError = error(Bsca,trialBsca)
         if scaError_prev - scaError < 0:
           nStep *= -1
@@ -478,7 +624,7 @@ def IterativeInversion_withSizeDistribution(Bsca,Babs,wavelength,diameterBins,si
           break
         absError_prev = absError
         m = m + kStep
-        trialBsca,trialBabs = fastMie_withSizeDistribution(m,wavelength,diameterBins,sizeDistribution)
+        trialBsca,trialBabs = fastMie_SD(m,wavelength,dp,ndp)
         absError = error(Babs,trialBabs)
         if absError_prev-absError < 0:
           kStep *= -1
@@ -492,7 +638,7 @@ def IterativeInversion_withSizeDistribution(Bsca,Babs,wavelength,diameterBins,si
         break
       scaError_prev = scaError
       m += nStep
-      trialBsca,trialBabs = fastMie_withSizeDistribution(m,wavelength,diameterBins,sizeDistribution)
+      trialBsca,trialBabs = fastMie_SD(m,wavelength,dp,ndp)
       scaError = error(Bsca,trialBsca)
       if scaError_prev - scaError < 0:
         nStep *= -1
@@ -506,7 +652,7 @@ def IterativeInversion_withSizeDistribution(Bsca,Babs,wavelength,diameterBins,si
         break
       absError_prev = absError
       m += kStep
-      trialBsca,trialBabs = fastMie_withSizeDistribution(m,wavelength,diameterBins,sizeDistribution)
+      trialBsca,trialBabs = fastMie_SD(m,wavelength,dp,ndp)
       absError = error(Babs,trialBabs)
       if absError_prev - absError < 0:
         kStep *= -1
@@ -520,13 +666,13 @@ def IterativeInversion_withSizeDistribution(Bsca,Babs,wavelength,diameterBins,si
         break
       scaError_prev = scaError
       m += nStep
-      trialBsca,trialBabs = fastMie_withSizeDistribution(m,wavelength,diameterBins,sizeDistribution)
+      trialBsca,trialBabs = fastMie_SD(m,wavelength,dp,ndp)
       scaError = error(Bsca,trialBsca)
       if scaError_prev - scaError < 0:
         nStep *= -1
         flippyFloppy += 1
 
-    trialBsca,trialBabs = fastMie_withSizeDistribution(m,wavelength,diameterBins,sizeDistribution)
+    trialBsca,trialBabs = fastMie_SD(m,wavelength,dp,ndp)
     scaError = error(Bsca,trialBsca)
     absError = error(Babs,trialBabs)
     resultM.append(m)
@@ -538,18 +684,18 @@ def IterativeInversion_withSizeDistribution(Bsca,Babs,wavelength,diameterBins,si
   else:
     return resultM, resultScaErr, resultAbsErr
 
-def fastMie_withSizeDistribution(m, wavelength, sizeDistributionDiameterBins, sizeDistribution):
-#  http://pymiescatt.readthedocs.io/en/latest/inverse.html#fastMie_WithSizeDistribution
-  sizeDistributionDiameterBins = coerceDType(sizeDistributionDiameterBins)
-  sizeDistribution = coerceDType(sizeDistribution)
-  _length = np.size(sizeDistributionDiameterBins)
+def fastMie_SD(m, wavelength, ndpdp, ndp):
+#  http://pymiescatt.readthedocs.io/en/latest/inverse.html#fastMie_SD
+  ndpdp = coerceDType(ndpdp)
+  ndp = coerceDType(ndp)
+  _length = np.size(ndpdp)
   Q_sca = np.zeros(_length)
   Q_abs = np.zeros(_length)
 
-  aSDn = np.pi*((sizeDistributionDiameterBins/2)**2)*sizeDistribution*(1e-6)
+  aSDn = np.pi*((ndpdp/2)**2)*ndp*(1e-6)
 
   for i in range(_length):
-    Q_sca[i],Q_abs[i],_ = fastMieQ(m,wavelength,sizeDistributionDiameterBins[i])
+    Q_sca[i],Q_abs[i],_ = fastMieQ(m,wavelength,ndpdp[i])
 
   Bsca = trapz(Q_sca*aSDn)
   Babs = trapz(Q_abs*aSDn)
